@@ -37,7 +37,7 @@ class Database:
     def get() -> list:
         r = RethinkDB()
         con = r.connect(db="jarvis")
-        con.check_open(types.MethodType(Database.auto_reconnect, con))
+        con.check_open = types.MethodType(Database.auto_reconnect, con)
         con.noreply_wait()
         return [r, con]
     
